import enum


class Counties(enum.Enum):
    USTRIA = 'at_AT'
    BELGIUM = 'fr_BE'
    CZECH_REPUBLIC = 'cz_CZ'
    GERMANY = 'de_DE'
    DENMARK = 'da_DK'
    SPAIN = 'es_ES'
    FINLAND = 'fi_FI'
    FRANCE = 'fr_FR'
    HONG_KONG = 'en_HK'
    CROATIA = 'hr_HR'
    HUNGARY = 'hu_HU'
    INDONESIA = 'id_ID'
    ISRAIL = 'he_IL'
    IRAN = 'fa_IR'
    ITALY = 'it_IT'
    JAPAN = 'ja_JP'
    SOUTH_KOREA = 'ko_KR'
    LITHUANIA = 'lt_LT'
    LATVIA = 'lv_lv'
    MALAYSIA = 'ms_MY'
    NIGERIA = 'en_NG'
    NETHERLANDS = 'nl_NL'
    NEPAL = 'ne_NP'
    NEW_ZEALAND = 'en_NZ'
    PERU = 'es_PE'
    SAUDI_ARABIA = 'ar_SA'
    USA = 'en_US'
    VENEZUELA = 'es_VE'
    SOUTH_AFRICA = 'en_ZA'
