import enum


class Domains(enum.Enum):
    GMAILNATOR_COM = ['{}@gmailnator.com']
    PSNATOR_COM = ['{}@psnator.com']
    GMAIL_COM = ['claytmp+{}@gmail.com',
                 'ednatmp+{}@gmail.com',
                 'tinytmp+{}@gmail.com',
                 'irontmp+{}@gmail.com',
                 'combtmp+{}@gmail.com',
                 'dueltmp+{}@gmail.com',
                 'aveltmp+{}@gmail.com',
                 'sisatmp+{}@gmail.com',
                 'wipetmp+{}@gmail.com',
                 'jocktmp+{}@gmail.com',
                 'daratmp+{}@gmail.com',
                 'joneltmp+{}@gmail.com',
                 'hcarrieyt+{}@gmail.com',
                 'hjefferyt+{}@gmail.com']
